Report

Go to page content

# Dexy Run Report

## Results of your Run

This is a logfile to help you understand how dexy has processed your files and to assist with troubleshooting.

### Timing

The total elapsed time for batch 1001 was 2.74 (0.05 minutes).

### Config

This is the configuration which was used for this run:

    Directory .:
    ### @export "docs"
    docs:
        - index.html|jinja|markdown|htmlsections:
            - ws_template : '_home_template.html'
        - .md|jinja|markdown:
            - meta
            - source

    ### @export "assets"
    assets:
        - .css
        - .js
        - .png
        - .jpg

    ### @export "source"
    source:
        - .txt
        - .md
        - "*/_*.html|pyg|-":
            - canon : True
            - ws_template : False

    ### @export "meta"
    meta:
        - list-reports.sh|shint|pyg:
            - contents : "dexy reporters"
        - .jinja|pyg
        - .yaml|idio
        - .html|pyg
        - .md|idio:
            - idio: { lexer : jinja }
        - dexy.conf|pyg:
            - pyg: { lexer : yaml }

    Directory ./about:
    ### @export "content-demos"
    - simple_content.html:
        - ws_template: _simple_template.html

    - head_body_content.html|htmlsections:
        - ws_template: _head_body_template.html

    ### @export "introspect"
    - introspect.html:
        - contents: " "
        - ws_template: _introspect_template.html

# 10 Slowest Tasks

- 0.903 - list-reports.sh|shint (generated)
- 0.053 - about/_head_body_template.html|pyg (generated)
- 0.043 - list-reports.sh|shint|pyg (generated)
- 0.040 - about/index.md|jinja (generated)
- 0.040 - about/head_body_content.html|pyg (generated)
- 0.034 - macros/_banner.html|pyg (generated)
- 0.033 - dexy.yaml|idio (generated)
- 0.033 - index.html|jinja (generated)
- 0.031 - about/_introspect_template.html|pyg (generated)
- 0.030 - index.html|pyg (generated)

# Documents

## index.html|jinja|markdown|htmlsections ↑

#### Arguments

    ws_template: _home_template.html

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
index.html | artifacts/efaa08f3193f81081e9d84bf5c741499.html | 0.0000 |  |
index.html|jinja | artifacts/5fe7936bb7827e9cb3eb2bd800bf320c.html | 0.0327 | generated |
index.html|jinja|markdown | artifacts/8df6f757600833321c74c31b8fe88731.html | 0.0096 | generated |
index.html|jinja|markdown|htmlsections | artifacts/b547b181911b01beeeb44fd5807ed07d.json | 0.0006 | generated | one two three four

#### Document Log

    2012-11-19 23:27:34,439 - index.html|jinja - DEBUG - Setting up FilterArtifact:index.html|jinja::Doc:index.html|jinja|markdown|htmlsections
    2012-11-19 23:27:34,440 - index.html|jinja - DEBUG - Setting hashstring for index.html|jinja to 5fe7936bb7827e9cb3eb2bd800bf320c
    2012-11-19 23:27:34,440 - index.html|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 23:27:34,440 - index.html|jinja|markdown - DEBUG - Setting up FilterArtifact:index.html|jinja|markdown::Doc:index.html|jinja|markdown|htmlsections
    2012-11-19 23:27:34,441 - index.html|jinja|markdown - DEBUG - Setting hashstring for index.html|jinja|markdown to 8df6f757600833321c74c31b8fe88731
    2012-11-19 23:27:34,441 - index.html|jinja|markdown - DEBUG - setting up output data of class GenericData
    2012-11-19 23:27:34,441 - index.html|jinja|markdown|htmlsections - DEBUG - Setting up FilterArtifact:index.html|jinja|markdown|htmlsections::Doc:index.html|jinja|markdown|htmlsections
    2012-11-19 23:27:34,441 - index.html|jinja|markdown|htmlsections - DEBUG - Setting hashstring for index.html|jinja|markdown|htmlsections to b547b181911b01beeeb44fd5807ed07d
    2012-11-19 23:27:34,441 - index.html|jinja|markdown|htmlsections - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,519 - index.html|jinja - DEBUG - Running FilterArtifact:index.html|jinja::Doc:index.html|jinja|markdown|htmlsections
    2012-11-19 23:27:34,519 - index.html|jinja - DEBUG - Output is not cached under 5fe7936bb7827e9cb3eb2bd800bf320c, running...
    2012-11-19 23:27:34,519 - index.html|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/5fe7936bb7827e9cb3eb2bd800bf320c/, artifacts/5fe7936bb7827e9cb3eb2bd800bf320c
    2012-11-19 23:27:34,520 - index.html|jinja - DEBUG - setting up jinja environment
    2012-11-19 23:27:34,520 - index.html|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-19 23:27:34,520 - index.html|jinja - DEBUG - initializing template
    2012-11-19 23:27:34,520 - index.html|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-19 23:27:34,520 - index.html|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-19 23:27:34,520 - index.html|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-19 23:27:34,520 - index.html|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-19 23:27:34,520 - index.html|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-19 23:27:34,520 - index.html|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-19 23:27:34,520 - index.html|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-19 23:27:34,521 - index.html|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-19 23:27:34,547 - index.html|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-19 23:27:34,547 - index.html|jinja - DEBUG - Running template plugin Variables
    2012-11-19 23:27:34,548 - index.html|jinja - DEBUG - Running template plugin Globals
    2012-11-19 23:27:34,548 - index.html|jinja - DEBUG - Running template plugin Inputs
    2012-11-19 23:27:34,548 - index.html|jinja - DEBUG - relative refs are []
    2012-11-19 23:27:34,548 - index.html|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-19 23:27:34,548 - index.html|jinja - DEBUG - about to create jinja template
    2012-11-19 23:27:34,551 - index.html|jinja - DEBUG - about to process jinja template
    2012-11-19 23:27:34,552 - index.html|jinja|markdown - DEBUG - Running FilterArtifact:index.html|jinja|markdown::Doc:index.html|jinja|markdown|htmlsections
    2012-11-19 23:27:34,552 - index.html|jinja|markdown - DEBUG - Output is not cached under 8df6f757600833321c74c31b8fe88731, running...
    2012-11-19 23:27:34,552 - index.html|jinja|markdown - DEBUG - Initializing Markdown with extensions: ["toc"] and extension configs: {"toc": {}}
    2012-11-19 23:27:34,562 - index.html|jinja|markdown|htmlsections - DEBUG - Running FilterArtifact:index.html|jinja|markdown|htmlsections::Doc:index.html|jinja|markdown|htmlsections
    2012-11-19 23:27:34,562 - index.html|jinja|markdown|htmlsections - DEBUG - Output is not cached under b547b181911b01beeeb44fd5807ed07d, running...

## list-reports.sh|shint|pyg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
list-reports.sh | artifacts/65511dd3f1b20ccf36304f6112fc8fe2.sh | 0.0000 |  |
list-reports.sh|shint | artifacts/8cf0e7954a1d1f5b10c9a475060ba47e.sh-session | 0.9027 | generated | 1
list-reports.sh|shint|pyg | artifacts/db569f0a959df12e9cc901798d0843c7.html | 0.0428 | generated | 1

#### Document Log

    2012-11-19 23:27:34,442 - list-reports.sh|shint - DEBUG - Setting up FilterArtifact:list-reports.sh|shint::Doc:list-reports.sh|shint|pyg
    2012-11-19 23:27:34,442 - list-reports.sh|shint - DEBUG - Setting hashstring for list-reports.sh|shint to 8cf0e7954a1d1f5b10c9a475060ba47e
    2012-11-19 23:27:34,443 - list-reports.sh|shint - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,443 - list-reports.sh|shint|pyg - DEBUG - Setting up FilterArtifact:list-reports.sh|shint|pyg::Doc:list-reports.sh|shint|pyg
    2012-11-19 23:27:34,443 - list-reports.sh|shint|pyg - DEBUG - Setting hashstring for list-reports.sh|shint|pyg to db569f0a959df12e9cc901798d0843c7
    2012-11-19 23:27:34,443 - list-reports.sh|shint|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,563 - list-reports.sh|shint - DEBUG - Running FilterArtifact:list-reports.sh|shint::Doc:list-reports.sh|shint|pyg
    2012-11-19 23:27:34,563 - list-reports.sh|shint - DEBUG - Output is not cached under 8cf0e7954a1d1f5b10c9a475060ba47e, running...
    2012-11-19 23:27:34,563 - list-reports.sh|shint - DEBUG - args:
    2012-11-19 23:27:34,563 - list-reports.sh|shint - DEBUG - Setting PS1 to $
    2012-11-19 23:27:34,563 - list-reports.sh|shint - DEBUG - About to spawn new process 'bash --norc -i' in artifacts/8cf0e7954a1d1f5b10c9a475060ba47e/.
    2012-11-19 23:27:34,565 - list-reports.sh|shint - DEBUG - Capturing initial prompt...
    2012-11-19 23:27:34,574 - list-reports.sh|shint - DEBUG - Initial prompt captured!
    2012-11-19 23:27:34,575 - list-reports.sh|shint - DEBUG - $
    2012-11-19 23:27:34,575 - list-reports.sh|shint - DEBUG - Sending 'dexy reporters'
    2012-11-19 23:27:35,308 - list-reports.sh|shint - DEBUG - Received ' dexy reporters
    ALIAS      DIRECTORY            INFO
    long       output-long          Creates complete dexy output with files given long, unique filenames.
    output     output               Creates canonical dexy output with files given short filenames.
    run
    ws         output-site          Applies a template to create a website from your dexy output.
    '
    2012-11-19 23:27:35,309 - list-reports.sh|shint - DEBUG - Sending '
    '
    2012-11-19 23:27:35,360 - list-reports.sh|shint - DEBUG - Received '
    '
    2012-11-19 23:27:35,361 - list-reports.sh|shint - DEBUG - Processing section 1
    2012-11-19 23:27:35,467 - list-reports.sh|shint|pyg - DEBUG - Running FilterArtifact:list-reports.sh|shint|pyg::Doc:list-reports.sh|shint|pyg
    2012-11-19 23:27:35,467 - list-reports.sh|shint|pyg - DEBUG - Output is not cached under db569f0a959df12e9cc901798d0843c7, running...
    2012-11-19 23:27:35,504 - list-reports.sh|shint|pyg - DEBUG - Using lexer BashSessionLexer

## macros/nav.jinja|pyg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
macros/nav.jinja | artifacts/01e83c57fbd370d876c7536ecf02b27d.jinja | 0.0000 |  |
macros/nav.jinja|pyg | artifacts/9a0bc1dda8198e51bb406582b12cd8dc.html | 0.0062 | generated | 1

#### Document Log

    2012-11-19 23:27:34,444 - macros/nav.jinja|pyg - DEBUG - Setting up FilterArtifact:macros/nav.jinja|pyg::Doc:macros/nav.jinja|pyg
    2012-11-19 23:27:34,444 - macros/nav.jinja|pyg - DEBUG - Setting hashstring for macros/nav.jinja|pyg to 9a0bc1dda8198e51bb406582b12cd8dc
    2012-11-19 23:27:34,444 - macros/nav.jinja|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:35,510 - macros/nav.jinja|pyg - DEBUG - Running FilterArtifact:macros/nav.jinja|pyg::Doc:macros/nav.jinja|pyg
    2012-11-19 23:27:35,510 - macros/nav.jinja|pyg - DEBUG - Output is not cached under 9a0bc1dda8198e51bb406582b12cd8dc, running...
    2012-11-19 23:27:35,514 - macros/nav.jinja|pyg - DEBUG - Using lexer DjangoLexer

## dexy.yaml|idio ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
dexy.yaml | artifacts/4d8ee186a1a656e6fd2d653f8c5250fa.yaml | 0.0000 |  |
dexy.yaml|idio | artifacts/f8cf89a9530b43f07c5ee6fcaacb57fa.html | 0.0333 | generated | 1 docs assets source meta

#### Document Log

    2012-11-19 23:27:34,445 - dexy.yaml|idio - DEBUG - Setting up FilterArtifact:dexy.yaml|idio::Doc:dexy.yaml|idio
    2012-11-19 23:27:34,445 - dexy.yaml|idio - DEBUG - Setting hashstring for dexy.yaml|idio to f8cf89a9530b43f07c5ee6fcaacb57fa
    2012-11-19 23:27:34,446 - dexy.yaml|idio - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:35,516 - dexy.yaml|idio - DEBUG - Running FilterArtifact:dexy.yaml|idio::Doc:dexy.yaml|idio
    2012-11-19 23:27:35,517 - dexy.yaml|idio - DEBUG - Output is not cached under f8cf89a9530b43f07c5ee6fcaacb57fa, running...
    2012-11-19 23:27:35,544 - dexy.yaml|idio - DEBUG - Using lexer YamlLexer
    2012-11-19 23:27:35,546 - dexy.yaml|idio - DEBUG - In section no. 0 name 1
    2012-11-19 23:27:35,547 - dexy.yaml|idio - DEBUG - In section no. 1 name docs
    2012-11-19 23:27:35,547 - dexy.yaml|idio - DEBUG - In section no. 2 name assets
    2012-11-19 23:27:35,548 - dexy.yaml|idio - DEBUG - In section no. 3 name source
    2012-11-19 23:27:35,548 - dexy.yaml|idio - DEBUG - In section no. 4 name meta

## about/dexy.yaml|idio ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
about/dexy.yaml | artifacts/380abd4544a55ee887a98583b6ae7af3.yaml | 0.0000 |  |
about/dexy.yaml|idio | artifacts/4043a580888d2572227ef24221fc5ca8.html | 0.0254 | generated | 1 content-demos introspect

#### Document Log

    2012-11-19 23:27:34,446 - about/dexy.yaml|idio - DEBUG - Setting up FilterArtifact:about/dexy.yaml|idio::Doc:about/dexy.yaml|idio
    2012-11-19 23:27:34,447 - about/dexy.yaml|idio - DEBUG - Setting hashstring for about/dexy.yaml|idio to 4043a580888d2572227ef24221fc5ca8
    2012-11-19 23:27:34,447 - about/dexy.yaml|idio - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:35,550 - about/dexy.yaml|idio - DEBUG - Running FilterArtifact:about/dexy.yaml|idio::Doc:about/dexy.yaml|idio
    2012-11-19 23:27:35,550 - about/dexy.yaml|idio - DEBUG - Output is not cached under 4043a580888d2572227ef24221fc5ca8, running...
    2012-11-19 23:27:35,573 - about/dexy.yaml|idio - DEBUG - Using lexer YamlLexer
    2012-11-19 23:27:35,574 - about/dexy.yaml|idio - DEBUG - In section no. 0 name 1
    2012-11-19 23:27:35,574 - about/dexy.yaml|idio - DEBUG - In section no. 1 name content-demos
    2012-11-19 23:27:35,575 - about/dexy.yaml|idio - DEBUG - In section no. 2 name introspect

## index.html|pyg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
index.html | artifacts/efaa08f3193f81081e9d84bf5c741499.html | 0.0000 |  |
index.html|pyg | artifacts/acec530d5fb0ed29fe6b9a58a57a4a5c.html | 0.0302 | generated | 1

#### Document Log

    2012-11-19 23:27:34,447 - index.html|pyg - DEBUG - Setting up FilterArtifact:index.html|pyg::Doc:index.html|pyg
    2012-11-19 23:27:34,448 - index.html|pyg - DEBUG - Setting hashstring for index.html|pyg to acec530d5fb0ed29fe6b9a58a57a4a5c
    2012-11-19 23:27:34,448 - index.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:35,576 - index.html|pyg - DEBUG - Running FilterArtifact:index.html|pyg::Doc:index.html|pyg
    2012-11-19 23:27:35,576 - index.html|pyg - DEBUG - Output is not cached under acec530d5fb0ed29fe6b9a58a57a4a5c, running...
    2012-11-19 23:27:35,601 - index.html|pyg - DEBUG - Using lexer HtmlLexer

## _template.html|pyg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
_template.html | artifacts/36cf47f96c49209081b14b7a956966d3.html | 0.0000 |  |
_template.html|pyg | artifacts/5861d4fce6117a1cef1cfc386cc78ba9.html | 0.0241 | generated | 1

#### Document Log

    2012-11-19 23:27:34,449 - _template.html|pyg - DEBUG - Setting up FilterArtifact:_template.html|pyg::Doc:_template.html|pyg
    2012-11-19 23:27:34,449 - _template.html|pyg - DEBUG - Setting hashstring for _template.html|pyg to 5861d4fce6117a1cef1cfc386cc78ba9
    2012-11-19 23:27:34,449 - _template.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:35,607 - _template.html|pyg - DEBUG - Running FilterArtifact:_template.html|pyg::Doc:_template.html|pyg
    2012-11-19 23:27:35,607 - _template.html|pyg - DEBUG - Output is not cached under 5861d4fce6117a1cef1cfc386cc78ba9, running...
    2012-11-19 23:27:35,629 - _template.html|pyg - DEBUG - Using lexer HtmlLexer

## _home_template.html|pyg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
_home_template.html | artifacts/dc57496e91caff78be99a783af6c7ce2.html | 0.0000 |  |
_home_template.html|pyg | artifacts/5c35dfb52ecb6e5da36192236d46bc96.html | 0.0248 | generated | 1

#### Document Log

    2012-11-19 23:27:34,450 - _home_template.html|pyg - DEBUG - Setting up FilterArtifact:_home_template.html|pyg::Doc:_home_template.html|pyg
    2012-11-19 23:27:34,450 - _home_template.html|pyg - DEBUG - Setting hashstring for _home_template.html|pyg to 5c35dfb52ecb6e5da36192236d46bc96
    2012-11-19 23:27:34,450 - _home_template.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:35,631 - _home_template.html|pyg - DEBUG - Running FilterArtifact:_home_template.html|pyg::Doc:_home_template.html|pyg
    2012-11-19 23:27:35,631 - _home_template.html|pyg - DEBUG - Output is not cached under 5c35dfb52ecb6e5da36192236d46bc96, running...
    2012-11-19 23:27:35,654 - _home_template.html|pyg - DEBUG - Using lexer HtmlLexer

## _base.html|pyg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
_base.html | artifacts/4ddf28121305d65f13f00955bd7aeaa9.html | 0.0000 |  |
_base.html|pyg | artifacts/8538181c0622993af5e8f3439832f7d5.html | 0.0252 | generated | 1

#### Document Log

    2012-11-19 23:27:34,451 - _base.html|pyg - DEBUG - Setting up FilterArtifact:_base.html|pyg::Doc:_base.html|pyg
    2012-11-19 23:27:34,451 - _base.html|pyg - DEBUG - Setting hashstring for _base.html|pyg to 8538181c0622993af5e8f3439832f7d5
    2012-11-19 23:27:34,452 - _base.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:35,656 - _base.html|pyg - DEBUG - Running FilterArtifact:_base.html|pyg::Doc:_base.html|pyg
    2012-11-19 23:27:35,656 - _base.html|pyg - DEBUG - Output is not cached under 8538181c0622993af5e8f3439832f7d5, running...
    2012-11-19 23:27:35,679 - _base.html|pyg - DEBUG - Using lexer HtmlLexer

## macros/_header.html|pyg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
macros/_header.html | artifacts/19bb4fd2644f20a43921f946a5f41dd8.html | 0.0000 |  |
macros/_header.html|pyg | artifacts/8414a7cddda96fb271d2a25515211466.html | 0.0248 | generated | 1

#### Document Log

    2012-11-19 23:27:34,452 - macros/_header.html|pyg - DEBUG - Setting up FilterArtifact:macros/_header.html|pyg::Doc:macros/_header.html|pyg
    2012-11-19 23:27:34,453 - macros/_header.html|pyg - DEBUG - Setting hashstring for macros/_header.html|pyg to 8414a7cddda96fb271d2a25515211466
    2012-11-19 23:27:34,453 - macros/_header.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,471 - macros/_header.html|pyg - DEBUG - Setting up FilterArtifact:macros/_header.html|pyg::Doc:macros/_header.html|pyg|-
    2012-11-19 23:27:34,471 - macros/_header.html|pyg - DEBUG - Setting hashstring for macros/_header.html|pyg to 922e2d95ebb2c483130ae1bfcd7bb207
    2012-11-19 23:27:34,471 - macros/_header.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:35,682 - macros/_header.html|pyg - DEBUG - Running FilterArtifact:macros/_header.html|pyg::Doc:macros/_header.html|pyg
    2012-11-19 23:27:35,682 - macros/_header.html|pyg - DEBUG - Output is not cached under 8414a7cddda96fb271d2a25515211466, running...
    2012-11-19 23:27:35,705 - macros/_header.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:35,927 - macros/_header.html|pyg - DEBUG - Running FilterArtifact:macros/_header.html|pyg::Doc:macros/_header.html|pyg|-
    2012-11-19 23:27:35,928 - macros/_header.html|pyg - DEBUG - Output is not cached under 922e2d95ebb2c483130ae1bfcd7bb207, running...
    2012-11-19 23:27:35,950 - macros/_header.html|pyg - DEBUG - Using lexer HtmlLexer

## macros/_banner.html|pyg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
macros/_banner.html | artifacts/da8f5d50090992099220b91321b3aad2.html | 0.0000 |  |
macros/_banner.html|pyg | artifacts/4b6d5bbb0f175088f2da0310bae50f89.html | 0.0244 | generated | 1

#### Document Log

    2012-11-19 23:27:34,454 - macros/_banner.html|pyg - DEBUG - Setting up FilterArtifact:macros/_banner.html|pyg::Doc:macros/_banner.html|pyg
    2012-11-19 23:27:34,454 - macros/_banner.html|pyg - DEBUG - Setting hashstring for macros/_banner.html|pyg to 4b6d5bbb0f175088f2da0310bae50f89
    2012-11-19 23:27:34,454 - macros/_banner.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,472 - macros/_banner.html|pyg - DEBUG - Setting up FilterArtifact:macros/_banner.html|pyg::Doc:macros/_banner.html|pyg|-
    2012-11-19 23:27:34,473 - macros/_banner.html|pyg - DEBUG - Setting hashstring for macros/_banner.html|pyg to 77e4bac772de2f51a2a24319d9fc0a61
    2012-11-19 23:27:34,473 - macros/_banner.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:35,707 - macros/_banner.html|pyg - DEBUG - Running FilterArtifact:macros/_banner.html|pyg::Doc:macros/_banner.html|pyg
    2012-11-19 23:27:35,707 - macros/_banner.html|pyg - DEBUG - Output is not cached under 4b6d5bbb0f175088f2da0310bae50f89, running...
    2012-11-19 23:27:35,730 - macros/_banner.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:35,954 - macros/_banner.html|pyg - DEBUG - Running FilterArtifact:macros/_banner.html|pyg::Doc:macros/_banner.html|pyg|-
    2012-11-19 23:27:35,954 - macros/_banner.html|pyg - DEBUG - Output is not cached under 77e4bac772de2f51a2a24319d9fc0a61, running...
    2012-11-19 23:27:35,985 - macros/_banner.html|pyg - DEBUG - Using lexer HtmlLexer

## macros/_logo.html|pyg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
macros/_logo.html | artifacts/8c7efbf47ab20aeac109479feeb9e1c3.html | 0.0000 |  |
macros/_logo.html|pyg | artifacts/3b106611a625b53e881c1196f3289a87.html | 0.0242 | generated | 1

#### Document Log

    2012-11-19 23:27:34,455 - macros/_logo.html|pyg - DEBUG - Setting up FilterArtifact:macros/_logo.html|pyg::Doc:macros/_logo.html|pyg
    2012-11-19 23:27:34,456 - macros/_logo.html|pyg - DEBUG - Setting hashstring for macros/_logo.html|pyg to 3b106611a625b53e881c1196f3289a87
    2012-11-19 23:27:34,456 - macros/_logo.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,474 - macros/_logo.html|pyg - DEBUG - Setting up FilterArtifact:macros/_logo.html|pyg::Doc:macros/_logo.html|pyg|-
    2012-11-19 23:27:34,475 - macros/_logo.html|pyg - DEBUG - Setting hashstring for macros/_logo.html|pyg to 5642308ca9f25f2022126212ec4099fc
    2012-11-19 23:27:34,475 - macros/_logo.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:35,732 - macros/_logo.html|pyg - DEBUG - Running FilterArtifact:macros/_logo.html|pyg::Doc:macros/_logo.html|pyg
    2012-11-19 23:27:35,732 - macros/_logo.html|pyg - DEBUG - Output is not cached under 3b106611a625b53e881c1196f3289a87, running...
    2012-11-19 23:27:35,754 - macros/_logo.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:35,989 - macros/_logo.html|pyg - DEBUG - Running FilterArtifact:macros/_logo.html|pyg::Doc:macros/_logo.html|pyg|-
    2012-11-19 23:27:35,989 - macros/_logo.html|pyg - DEBUG - Output is not cached under 5642308ca9f25f2022126212ec4099fc, running...
    2012-11-19 23:27:36,011 - macros/_logo.html|pyg - DEBUG - Using lexer HtmlLexer

## macros/_footer.html|pyg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
macros/_footer.html | artifacts/349cccc1cde127a1d332077f28ccfc4e.html | 0.0000 |  |
macros/_footer.html|pyg | artifacts/c1c9b2d4f109bcce6e3460458b41c1e4.html | 0.0240 | generated | 1

#### Document Log

    2012-11-19 23:27:34,457 - macros/_footer.html|pyg - DEBUG - Setting up FilterArtifact:macros/_footer.html|pyg::Doc:macros/_footer.html|pyg
    2012-11-19 23:27:34,457 - macros/_footer.html|pyg - DEBUG - Setting hashstring for macros/_footer.html|pyg to c1c9b2d4f109bcce6e3460458b41c1e4
    2012-11-19 23:27:34,457 - macros/_footer.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,476 - macros/_footer.html|pyg - DEBUG - Setting up FilterArtifact:macros/_footer.html|pyg::Doc:macros/_footer.html|pyg|-
    2012-11-19 23:27:34,477 - macros/_footer.html|pyg - DEBUG - Setting hashstring for macros/_footer.html|pyg to 07895e391f9195d74e0e4f6a68f387df
    2012-11-19 23:27:34,477 - macros/_footer.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:35,757 - macros/_footer.html|pyg - DEBUG - Running FilterArtifact:macros/_footer.html|pyg::Doc:macros/_footer.html|pyg
    2012-11-19 23:27:35,757 - macros/_footer.html|pyg - DEBUG - Output is not cached under c1c9b2d4f109bcce6e3460458b41c1e4, running...
    2012-11-19 23:27:35,779 - macros/_footer.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:36,014 - macros/_footer.html|pyg - DEBUG - Running FilterArtifact:macros/_footer.html|pyg::Doc:macros/_footer.html|pyg|-
    2012-11-19 23:27:36,014 - macros/_footer.html|pyg - DEBUG - Output is not cached under 07895e391f9195d74e0e4f6a68f387df, running...
    2012-11-19 23:27:36,036 - macros/_footer.html|pyg - DEBUG - Using lexer HtmlLexer

## about/_simple_template.html|pyg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
about/_simple_template.html | artifacts/02b968a9a83817f166d0e235fd52f825.html | 0.0000 |  |
about/_simple_template.html|pyg | artifacts/05be32acaeb54a9f616e2370a8bd3988.html | 0.0235 | generated | 1

#### Document Log

    2012-11-19 23:27:34,458 - about/_simple_template.html|pyg - DEBUG - Setting up FilterArtifact:about/_simple_template.html|pyg::Doc:about/_simple_template.html|pyg
    2012-11-19 23:27:34,459 - about/_simple_template.html|pyg - DEBUG - Setting hashstring for about/_simple_template.html|pyg to 05be32acaeb54a9f616e2370a8bd3988
    2012-11-19 23:27:34,459 - about/_simple_template.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,478 - about/_simple_template.html|pyg - DEBUG - Setting up FilterArtifact:about/_simple_template.html|pyg::Doc:about/_simple_template.html|pyg|-
    2012-11-19 23:27:34,479 - about/_simple_template.html|pyg - DEBUG - Setting hashstring for about/_simple_template.html|pyg to c12165b3fc3064519a23acf3a7e0344e
    2012-11-19 23:27:34,479 - about/_simple_template.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:35,782 - about/_simple_template.html|pyg - DEBUG - Running FilterArtifact:about/_simple_template.html|pyg::Doc:about/_simple_template.html|pyg
    2012-11-19 23:27:35,782 - about/_simple_template.html|pyg - DEBUG - Output is not cached under 05be32acaeb54a9f616e2370a8bd3988, running...
    2012-11-19 23:27:35,804 - about/_simple_template.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:36,039 - about/_simple_template.html|pyg - DEBUG - Running FilterArtifact:about/_simple_template.html|pyg::Doc:about/_simple_template.html|pyg|-
    2012-11-19 23:27:36,039 - about/_simple_template.html|pyg - DEBUG - Output is not cached under c12165b3fc3064519a23acf3a7e0344e, running...
    2012-11-19 23:27:36,061 - about/_simple_template.html|pyg - DEBUG - Using lexer HtmlLexer

## about/simple_content.html|pyg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
about/simple_content.html | artifacts/a170d89a36fbab2de19e71d1704d71b2.html | 0.0000 |  |
about/simple_content.html|pyg | artifacts/e8bf01c2b7ada2ba17f9433ea7fd7b4d.html | 0.0235 | generated | 1

#### Document Log

    2012-11-19 23:27:34,461 - about/simple_content.html|pyg - DEBUG - Setting up FilterArtifact:about/simple_content.html|pyg::Doc:about/simple_content.html|pyg
    2012-11-19 23:27:34,461 - about/simple_content.html|pyg - DEBUG - Setting hashstring for about/simple_content.html|pyg to e8bf01c2b7ada2ba17f9433ea7fd7b4d
    2012-11-19 23:27:34,462 - about/simple_content.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:35,806 - about/simple_content.html|pyg - DEBUG - Running FilterArtifact:about/simple_content.html|pyg::Doc:about/simple_content.html|pyg
    2012-11-19 23:27:35,806 - about/simple_content.html|pyg - DEBUG - Output is not cached under e8bf01c2b7ada2ba17f9433ea7fd7b4d, running...
    2012-11-19 23:27:35,828 - about/simple_content.html|pyg - DEBUG - Using lexer HtmlLexer

## about/_head_body_template.html|pyg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
about/_head_body_template.html | artifacts/2ed8fba05414d158d64c922bebe0302a.html | 0.0000 |  |
about/_head_body_template.html|pyg | artifacts/9178200ceb4ed09bc39c82dbb5a7bf56.html | 0.0236 | generated | 1

#### Document Log

    2012-11-19 23:27:34,463 - about/_head_body_template.html|pyg - DEBUG - Setting up FilterArtifact:about/_head_body_template.html|pyg::Doc:about/_head_body_template.html|pyg
    2012-11-19 23:27:34,463 - about/_head_body_template.html|pyg - DEBUG - Setting hashstring for about/_head_body_template.html|pyg to 9178200ceb4ed09bc39c82dbb5a7bf56
    2012-11-19 23:27:34,463 - about/_head_body_template.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,480 - about/_head_body_template.html|pyg - DEBUG - Setting up FilterArtifact:about/_head_body_template.html|pyg::Doc:about/_head_body_template.html|pyg|-
    2012-11-19 23:27:34,481 - about/_head_body_template.html|pyg - DEBUG - Setting hashstring for about/_head_body_template.html|pyg to acc54891b2b22384f88c896ed6b06aae
    2012-11-19 23:27:34,481 - about/_head_body_template.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:35,830 - about/_head_body_template.html|pyg - DEBUG - Running FilterArtifact:about/_head_body_template.html|pyg::Doc:about/_head_body_template.html|pyg
    2012-11-19 23:27:35,830 - about/_head_body_template.html|pyg - DEBUG - Output is not cached under 9178200ceb4ed09bc39c82dbb5a7bf56, running...
    2012-11-19 23:27:35,852 - about/_head_body_template.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:36,063 - about/_head_body_template.html|pyg - DEBUG - Running FilterArtifact:about/_head_body_template.html|pyg::Doc:about/_head_body_template.html|pyg|-
    2012-11-19 23:27:36,064 - about/_head_body_template.html|pyg - DEBUG - Output is not cached under acc54891b2b22384f88c896ed6b06aae, running...
    2012-11-19 23:27:36,086 - about/_head_body_template.html|pyg - DEBUG - Using lexer HtmlLexer

## about/head_body_content.html|pyg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
about/head_body_content.html | artifacts/64fb5fff459c6f55211fbaa6be5f09e3.html | 0.0000 |  |
about/head_body_content.html|pyg | artifacts/10a135f623a123747f692dd84052063e.html | 0.0395 | generated | 1

#### Document Log

    2012-11-19 23:27:34,464 - about/head_body_content.html|pyg - DEBUG - Setting up FilterArtifact:about/head_body_content.html|pyg::Doc:about/head_body_content.html|pyg
    2012-11-19 23:27:34,465 - about/head_body_content.html|pyg - DEBUG - Setting hashstring for about/head_body_content.html|pyg to 10a135f623a123747f692dd84052063e
    2012-11-19 23:27:34,465 - about/head_body_content.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:35,855 - about/head_body_content.html|pyg - DEBUG - Running FilterArtifact:about/head_body_content.html|pyg::Doc:about/head_body_content.html|pyg
    2012-11-19 23:27:35,855 - about/head_body_content.html|pyg - DEBUG - Output is not cached under 10a135f623a123747f692dd84052063e, running...
    2012-11-19 23:27:35,877 - about/head_body_content.html|pyg - DEBUG - Using lexer HtmlLexer

## about/_introspect_template.html|pyg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
about/_introspect_template.html | artifacts/0c82ef73a0cf60dab40ba737db9c426c.html | 0.0000 |  |
about/_introspect_template.html|pyg | artifacts/f446a3577e67a18aea56f23b43b8eaa9.html | 0.0239 | generated | 1

#### Document Log

    2012-11-19 23:27:34,466 - about/_introspect_template.html|pyg - DEBUG - Setting up FilterArtifact:about/_introspect_template.html|pyg::Doc:about/_introspect_template.html|pyg
    2012-11-19 23:27:34,467 - about/_introspect_template.html|pyg - DEBUG - Setting hashstring for about/_introspect_template.html|pyg to f446a3577e67a18aea56f23b43b8eaa9
    2012-11-19 23:27:34,467 - about/_introspect_template.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,483 - about/_introspect_template.html|pyg - DEBUG - Setting up FilterArtifact:about/_introspect_template.html|pyg::Doc:about/_introspect_template.html|pyg|-
    2012-11-19 23:27:34,483 - about/_introspect_template.html|pyg - DEBUG - Setting hashstring for about/_introspect_template.html|pyg to aded6002a186af2d70d8c78dbf3ad7ec
    2012-11-19 23:27:34,483 - about/_introspect_template.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:35,895 - about/_introspect_template.html|pyg - DEBUG - Running FilterArtifact:about/_introspect_template.html|pyg::Doc:about/_introspect_template.html|pyg
    2012-11-19 23:27:35,895 - about/_introspect_template.html|pyg - DEBUG - Output is not cached under f446a3577e67a18aea56f23b43b8eaa9, running...
    2012-11-19 23:27:35,917 - about/_introspect_template.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:36,122 - about/_introspect_template.html|pyg - DEBUG - Running FilterArtifact:about/_introspect_template.html|pyg::Doc:about/_introspect_template.html|pyg|-
    2012-11-19 23:27:36,123 - about/_introspect_template.html|pyg - DEBUG - Output is not cached under aded6002a186af2d70d8c78dbf3ad7ec, running...
    2012-11-19 23:27:36,151 - about/_introspect_template.html|pyg - DEBUG - Using lexer HtmlLexer

## about/index.md|idio ↑

#### Arguments

    idio:
        lexer: jinja

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
about/index.md | artifacts/3d01035e5931d39dc8b3d72d2d627181.md | 0.0000 |  |
about/index.md|idio | artifacts/8cb4931f69acbc4ab95633e53c3d4927.html | 0.0053 | generated | 1

#### Document Log

    2012-11-19 23:27:34,468 - about/index.md|idio - DEBUG - Setting up FilterArtifact:about/index.md|idio::Doc:about/index.md|idio
    2012-11-19 23:27:34,468 - about/index.md|idio - DEBUG - Setting hashstring for about/index.md|idio to 8cb4931f69acbc4ab95633e53c3d4927
    2012-11-19 23:27:34,468 - about/index.md|idio - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:35,919 - about/index.md|idio - DEBUG - Running FilterArtifact:about/index.md|idio::Doc:about/index.md|idio
    2012-11-19 23:27:35,920 - about/index.md|idio - DEBUG - Output is not cached under 8cb4931f69acbc4ab95633e53c3d4927, running...
    2012-11-19 23:27:35,920 - about/index.md|idio - DEBUG - custom lexer alias jinja specified
    2012-11-19 23:27:35,920 - about/index.md|idio - DEBUG - Using lexer DjangoLexer
    2012-11-19 23:27:35,922 - about/index.md|idio - DEBUG - In section no. 0 name 1

## dexy.conf|pyg ↑

#### Arguments

    pyg:
        lexer: yaml

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
dexy.conf | artifacts/0ae81d6f28c355acab4c684768673a6b.conf | 0.0000 |  |
dexy.conf|pyg | artifacts/7442b7b26eedb498e1d74c7efe013a86.html | 0.0013 | generated | 1

#### Document Log

    2012-11-19 23:27:34,469 - dexy.conf|pyg - DEBUG - Setting up FilterArtifact:dexy.conf|pyg::Doc:dexy.conf|pyg
    2012-11-19 23:27:34,469 - dexy.conf|pyg - DEBUG - Setting hashstring for dexy.conf|pyg to 7442b7b26eedb498e1d74c7efe013a86
    2012-11-19 23:27:34,469 - dexy.conf|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:35,925 - dexy.conf|pyg - DEBUG - Running FilterArtifact:dexy.conf|pyg::Doc:dexy.conf|pyg
    2012-11-19 23:27:35,925 - dexy.conf|pyg - DEBUG - Output is not cached under 7442b7b26eedb498e1d74c7efe013a86, running...
    2012-11-19 23:27:35,926 - dexy.conf|pyg - DEBUG - custom lexer alias yaml specified
    2012-11-19 23:27:35,926 - dexy.conf|pyg - DEBUG - Using lexer YamlLexer

## about/index.md ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
about/index.md | artifacts/3d01035e5931d39dc8b3d72d2d627181.md | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,467 - about/index.md - DEBUG - Setting up InitialArtifact:about/index.md::Doc:about/index.md|idio
    2012-11-19 23:27:34,467 - about/index.md - DEBUG - Setting hashstring for about/index.md to 3d01035e5931d39dc8b3d72d2d627181
    2012-11-19 23:27:34,467 - about/index.md - DEBUG - setting up output data of class GenericData
    2012-11-19 23:27:34,470 - about/index.md - DEBUG - Setting up InitialArtifact:about/index.md::Doc:about/index.md
    2012-11-19 23:27:34,470 - about/index.md - DEBUG - Setting hashstring for about/index.md to 3d01035e5931d39dc8b3d72d2d627181
    2012-11-19 23:27:34,470 - about/index.md - DEBUG - setting up output data of class GenericData
    2012-11-19 23:27:34,485 - about/index.md - DEBUG - Setting up InitialArtifact:about/index.md::Doc:about/index.md|jinja|markdown
    2012-11-19 23:27:34,485 - about/index.md - DEBUG - Setting hashstring for about/index.md to 3d01035e5931d39dc8b3d72d2d627181
    2012-11-19 23:27:34,485 - about/index.md - DEBUG - setting up output data of class GenericData

## macros/_header.html|pyg|- ↑

#### Arguments

    ws_template: False
    canon: True

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
macros/_header.html | artifacts/19bb4fd2644f20a43921f946a5f41dd8.html | 0.0000 |  |
macros/_header.html|pyg | artifacts/922e2d95ebb2c483130ae1bfcd7bb207.html | 0.0254 | generated | 1
macros/_header.html|pyg|- | artifacts/2c386eaf91785502df1a6df08a85f08a.html | 0.0004 | generated |

#### Document Log

    2012-11-19 23:27:34,452 - macros/_header.html|pyg - DEBUG - Setting up FilterArtifact:macros/_header.html|pyg::Doc:macros/_header.html|pyg
    2012-11-19 23:27:34,453 - macros/_header.html|pyg - DEBUG - Setting hashstring for macros/_header.html|pyg to 8414a7cddda96fb271d2a25515211466
    2012-11-19 23:27:34,453 - macros/_header.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,471 - macros/_header.html|pyg - DEBUG - Setting up FilterArtifact:macros/_header.html|pyg::Doc:macros/_header.html|pyg|-
    2012-11-19 23:27:34,471 - macros/_header.html|pyg - DEBUG - Setting hashstring for macros/_header.html|pyg to 922e2d95ebb2c483130ae1bfcd7bb207
    2012-11-19 23:27:34,471 - macros/_header.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,471 - macros/_header.html|pyg|- - DEBUG - Setting up FilterArtifact:macros/_header.html|pyg|-::Doc:macros/_header.html|pyg|-
    2012-11-19 23:27:34,472 - macros/_header.html|pyg|- - DEBUG - Setting hashstring for macros/_header.html|pyg|- to 2c386eaf91785502df1a6df08a85f08a
    2012-11-19 23:27:34,472 - macros/_header.html|pyg|- - DEBUG - setting up output data of class GenericData
    2012-11-19 23:27:35,682 - macros/_header.html|pyg - DEBUG - Running FilterArtifact:macros/_header.html|pyg::Doc:macros/_header.html|pyg
    2012-11-19 23:27:35,682 - macros/_header.html|pyg - DEBUG - Output is not cached under 8414a7cddda96fb271d2a25515211466, running...
    2012-11-19 23:27:35,705 - macros/_header.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:35,927 - macros/_header.html|pyg - DEBUG - Running FilterArtifact:macros/_header.html|pyg::Doc:macros/_header.html|pyg|-
    2012-11-19 23:27:35,928 - macros/_header.html|pyg - DEBUG - Output is not cached under 922e2d95ebb2c483130ae1bfcd7bb207, running...
    2012-11-19 23:27:35,950 - macros/_header.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:35,953 - macros/_header.html|pyg|- - DEBUG - Running FilterArtifact:macros/_header.html|pyg|-::Doc:macros/_header.html|pyg|-
    2012-11-19 23:27:35,953 - macros/_header.html|pyg|- - DEBUG - Output is not cached under 2c386eaf91785502df1a6df08a85f08a, running...

## macros/_banner.html|pyg|- ↑

#### Arguments

    ws_template: False
    canon: True

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
macros/_banner.html | artifacts/da8f5d50090992099220b91321b3aad2.html | 0.0000 |  |
macros/_banner.html|pyg | artifacts/77e4bac772de2f51a2a24319d9fc0a61.html | 0.0341 | generated | 1
macros/_banner.html|pyg|- | artifacts/ab2462f7f1096393cb33a38e2d33d1fd.html | 0.0003 | generated |

#### Document Log

    2012-11-19 23:27:34,454 - macros/_banner.html|pyg - DEBUG - Setting up FilterArtifact:macros/_banner.html|pyg::Doc:macros/_banner.html|pyg
    2012-11-19 23:27:34,454 - macros/_banner.html|pyg - DEBUG - Setting hashstring for macros/_banner.html|pyg to 4b6d5bbb0f175088f2da0310bae50f89
    2012-11-19 23:27:34,454 - macros/_banner.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,472 - macros/_banner.html|pyg - DEBUG - Setting up FilterArtifact:macros/_banner.html|pyg::Doc:macros/_banner.html|pyg|-
    2012-11-19 23:27:34,473 - macros/_banner.html|pyg - DEBUG - Setting hashstring for macros/_banner.html|pyg to 77e4bac772de2f51a2a24319d9fc0a61
    2012-11-19 23:27:34,473 - macros/_banner.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,473 - macros/_banner.html|pyg|- - DEBUG - Setting up FilterArtifact:macros/_banner.html|pyg|-::Doc:macros/_banner.html|pyg|-
    2012-11-19 23:27:34,474 - macros/_banner.html|pyg|- - DEBUG - Setting hashstring for macros/_banner.html|pyg|- to ab2462f7f1096393cb33a38e2d33d1fd
    2012-11-19 23:27:34,474 - macros/_banner.html|pyg|- - DEBUG - setting up output data of class GenericData
    2012-11-19 23:27:35,707 - macros/_banner.html|pyg - DEBUG - Running FilterArtifact:macros/_banner.html|pyg::Doc:macros/_banner.html|pyg
    2012-11-19 23:27:35,707 - macros/_banner.html|pyg - DEBUG - Output is not cached under 4b6d5bbb0f175088f2da0310bae50f89, running...
    2012-11-19 23:27:35,730 - macros/_banner.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:35,954 - macros/_banner.html|pyg - DEBUG - Running FilterArtifact:macros/_banner.html|pyg::Doc:macros/_banner.html|pyg|-
    2012-11-19 23:27:35,954 - macros/_banner.html|pyg - DEBUG - Output is not cached under 77e4bac772de2f51a2a24319d9fc0a61, running...
    2012-11-19 23:27:35,985 - macros/_banner.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:35,988 - macros/_banner.html|pyg|- - DEBUG - Running FilterArtifact:macros/_banner.html|pyg|-::Doc:macros/_banner.html|pyg|-
    2012-11-19 23:27:35,988 - macros/_banner.html|pyg|- - DEBUG - Output is not cached under ab2462f7f1096393cb33a38e2d33d1fd, running...

## macros/_logo.html|pyg|- ↑

#### Arguments

    ws_template: False
    canon: True

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
macros/_logo.html | artifacts/8c7efbf47ab20aeac109479feeb9e1c3.html | 0.0000 |  |
macros/_logo.html|pyg | artifacts/5642308ca9f25f2022126212ec4099fc.html | 0.0240 | generated | 1
macros/_logo.html|pyg|- | artifacts/f0e960ddc8682c02d2b128dc131e27ff.html | 0.0003 | generated |

#### Document Log

    2012-11-19 23:27:34,455 - macros/_logo.html|pyg - DEBUG - Setting up FilterArtifact:macros/_logo.html|pyg::Doc:macros/_logo.html|pyg
    2012-11-19 23:27:34,456 - macros/_logo.html|pyg - DEBUG - Setting hashstring for macros/_logo.html|pyg to 3b106611a625b53e881c1196f3289a87
    2012-11-19 23:27:34,456 - macros/_logo.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,474 - macros/_logo.html|pyg - DEBUG - Setting up FilterArtifact:macros/_logo.html|pyg::Doc:macros/_logo.html|pyg|-
    2012-11-19 23:27:34,475 - macros/_logo.html|pyg - DEBUG - Setting hashstring for macros/_logo.html|pyg to 5642308ca9f25f2022126212ec4099fc
    2012-11-19 23:27:34,475 - macros/_logo.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,475 - macros/_logo.html|pyg|- - DEBUG - Setting up FilterArtifact:macros/_logo.html|pyg|-::Doc:macros/_logo.html|pyg|-
    2012-11-19 23:27:34,476 - macros/_logo.html|pyg|- - DEBUG - Setting hashstring for macros/_logo.html|pyg|- to f0e960ddc8682c02d2b128dc131e27ff
    2012-11-19 23:27:34,476 - macros/_logo.html|pyg|- - DEBUG - setting up output data of class GenericData
    2012-11-19 23:27:35,732 - macros/_logo.html|pyg - DEBUG - Running FilterArtifact:macros/_logo.html|pyg::Doc:macros/_logo.html|pyg
    2012-11-19 23:27:35,732 - macros/_logo.html|pyg - DEBUG - Output is not cached under 3b106611a625b53e881c1196f3289a87, running...
    2012-11-19 23:27:35,754 - macros/_logo.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:35,989 - macros/_logo.html|pyg - DEBUG - Running FilterArtifact:macros/_logo.html|pyg::Doc:macros/_logo.html|pyg|-
    2012-11-19 23:27:35,989 - macros/_logo.html|pyg - DEBUG - Output is not cached under 5642308ca9f25f2022126212ec4099fc, running...
    2012-11-19 23:27:36,011 - macros/_logo.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:36,013 - macros/_logo.html|pyg|- - DEBUG - Running FilterArtifact:macros/_logo.html|pyg|-::Doc:macros/_logo.html|pyg|-
    2012-11-19 23:27:36,013 - macros/_logo.html|pyg|- - DEBUG - Output is not cached under f0e960ddc8682c02d2b128dc131e27ff, running...

## macros/_footer.html|pyg|- ↑

#### Arguments

    ws_template: False
    canon: True

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
macros/_footer.html | artifacts/349cccc1cde127a1d332077f28ccfc4e.html | 0.0000 |  |
macros/_footer.html|pyg | artifacts/07895e391f9195d74e0e4f6a68f387df.html | 0.0239 | generated | 1
macros/_footer.html|pyg|- | artifacts/664e27134fb6783446ec04b45cabbdf0.html | 0.0003 | generated |

#### Document Log

    2012-11-19 23:27:34,457 - macros/_footer.html|pyg - DEBUG - Setting up FilterArtifact:macros/_footer.html|pyg::Doc:macros/_footer.html|pyg
    2012-11-19 23:27:34,457 - macros/_footer.html|pyg - DEBUG - Setting hashstring for macros/_footer.html|pyg to c1c9b2d4f109bcce6e3460458b41c1e4
    2012-11-19 23:27:34,457 - macros/_footer.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,476 - macros/_footer.html|pyg - DEBUG - Setting up FilterArtifact:macros/_footer.html|pyg::Doc:macros/_footer.html|pyg|-
    2012-11-19 23:27:34,477 - macros/_footer.html|pyg - DEBUG - Setting hashstring for macros/_footer.html|pyg to 07895e391f9195d74e0e4f6a68f387df
    2012-11-19 23:27:34,477 - macros/_footer.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,477 - macros/_footer.html|pyg|- - DEBUG - Setting up FilterArtifact:macros/_footer.html|pyg|-::Doc:macros/_footer.html|pyg|-
    2012-11-19 23:27:34,478 - macros/_footer.html|pyg|- - DEBUG - Setting hashstring for macros/_footer.html|pyg|- to 664e27134fb6783446ec04b45cabbdf0
    2012-11-19 23:27:34,478 - macros/_footer.html|pyg|- - DEBUG - setting up output data of class GenericData
    2012-11-19 23:27:35,757 - macros/_footer.html|pyg - DEBUG - Running FilterArtifact:macros/_footer.html|pyg::Doc:macros/_footer.html|pyg
    2012-11-19 23:27:35,757 - macros/_footer.html|pyg - DEBUG - Output is not cached under c1c9b2d4f109bcce6e3460458b41c1e4, running...
    2012-11-19 23:27:35,779 - macros/_footer.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:36,014 - macros/_footer.html|pyg - DEBUG - Running FilterArtifact:macros/_footer.html|pyg::Doc:macros/_footer.html|pyg|-
    2012-11-19 23:27:36,014 - macros/_footer.html|pyg - DEBUG - Output is not cached under 07895e391f9195d74e0e4f6a68f387df, running...
    2012-11-19 23:27:36,036 - macros/_footer.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:36,038 - macros/_footer.html|pyg|- - DEBUG - Running FilterArtifact:macros/_footer.html|pyg|-::Doc:macros/_footer.html|pyg|-
    2012-11-19 23:27:36,038 - macros/_footer.html|pyg|- - DEBUG - Output is not cached under 664e27134fb6783446ec04b45cabbdf0, running...

## about/_simple_template.html|pyg|- ↑

#### Arguments

    ws_template: False
    canon: True

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
about/_simple_template.html | artifacts/02b968a9a83817f166d0e235fd52f825.html | 0.0000 |  |
about/_simple_template.html|pyg | artifacts/c12165b3fc3064519a23acf3a7e0344e.html | 0.0239 | generated | 1
about/_simple_template.html|pyg|- | artifacts/89e3d4a1b453ec31ea2d13d9e4cd5aaf.html | 0.0003 | generated |

#### Document Log

    2012-11-19 23:27:34,458 - about/_simple_template.html|pyg - DEBUG - Setting up FilterArtifact:about/_simple_template.html|pyg::Doc:about/_simple_template.html|pyg
    2012-11-19 23:27:34,459 - about/_simple_template.html|pyg - DEBUG - Setting hashstring for about/_simple_template.html|pyg to 05be32acaeb54a9f616e2370a8bd3988
    2012-11-19 23:27:34,459 - about/_simple_template.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,478 - about/_simple_template.html|pyg - DEBUG - Setting up FilterArtifact:about/_simple_template.html|pyg::Doc:about/_simple_template.html|pyg|-
    2012-11-19 23:27:34,479 - about/_simple_template.html|pyg - DEBUG - Setting hashstring for about/_simple_template.html|pyg to c12165b3fc3064519a23acf3a7e0344e
    2012-11-19 23:27:34,479 - about/_simple_template.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,479 - about/_simple_template.html|pyg|- - DEBUG - Setting up FilterArtifact:about/_simple_template.html|pyg|-::Doc:about/_simple_template.html|pyg|-
    2012-11-19 23:27:34,480 - about/_simple_template.html|pyg|- - DEBUG - Setting hashstring for about/_simple_template.html|pyg|- to 89e3d4a1b453ec31ea2d13d9e4cd5aaf
    2012-11-19 23:27:34,480 - about/_simple_template.html|pyg|- - DEBUG - setting up output data of class GenericData
    2012-11-19 23:27:35,782 - about/_simple_template.html|pyg - DEBUG - Running FilterArtifact:about/_simple_template.html|pyg::Doc:about/_simple_template.html|pyg
    2012-11-19 23:27:35,782 - about/_simple_template.html|pyg - DEBUG - Output is not cached under 05be32acaeb54a9f616e2370a8bd3988, running...
    2012-11-19 23:27:35,804 - about/_simple_template.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:36,039 - about/_simple_template.html|pyg - DEBUG - Running FilterArtifact:about/_simple_template.html|pyg::Doc:about/_simple_template.html|pyg|-
    2012-11-19 23:27:36,039 - about/_simple_template.html|pyg - DEBUG - Output is not cached under c12165b3fc3064519a23acf3a7e0344e, running...
    2012-11-19 23:27:36,061 - about/_simple_template.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:36,063 - about/_simple_template.html|pyg|- - DEBUG - Running FilterArtifact:about/_simple_template.html|pyg|-::Doc:about/_simple_template.html|pyg|-
    2012-11-19 23:27:36,063 - about/_simple_template.html|pyg|- - DEBUG - Output is not cached under 89e3d4a1b453ec31ea2d13d9e4cd5aaf, running...

## about/_head_body_template.html|pyg|- ↑

#### Arguments

    ws_template: False
    canon: True

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
about/_head_body_template.html | artifacts/2ed8fba05414d158d64c922bebe0302a.html | 0.0000 |  |
about/_head_body_template.html|pyg | artifacts/acc54891b2b22384f88c896ed6b06aae.html | 0.0527 | generated | 1
about/_head_body_template.html|pyg|- | artifacts/21f0887252d59463d4c53e3c63d7af96.html | 0.0019 | generated |

#### Document Log

    2012-11-19 23:27:34,463 - about/_head_body_template.html|pyg - DEBUG - Setting up FilterArtifact:about/_head_body_template.html|pyg::Doc:about/_head_body_template.html|pyg
    2012-11-19 23:27:34,463 - about/_head_body_template.html|pyg - DEBUG - Setting hashstring for about/_head_body_template.html|pyg to 9178200ceb4ed09bc39c82dbb5a7bf56
    2012-11-19 23:27:34,463 - about/_head_body_template.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,480 - about/_head_body_template.html|pyg - DEBUG - Setting up FilterArtifact:about/_head_body_template.html|pyg::Doc:about/_head_body_template.html|pyg|-
    2012-11-19 23:27:34,481 - about/_head_body_template.html|pyg - DEBUG - Setting hashstring for about/_head_body_template.html|pyg to acc54891b2b22384f88c896ed6b06aae
    2012-11-19 23:27:34,481 - about/_head_body_template.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,481 - about/_head_body_template.html|pyg|- - DEBUG - Setting up FilterArtifact:about/_head_body_template.html|pyg|-::Doc:about/_head_body_template.html|pyg|-
    2012-11-19 23:27:34,482 - about/_head_body_template.html|pyg|- - DEBUG - Setting hashstring for about/_head_body_template.html|pyg|- to 21f0887252d59463d4c53e3c63d7af96
    2012-11-19 23:27:34,482 - about/_head_body_template.html|pyg|- - DEBUG - setting up output data of class GenericData
    2012-11-19 23:27:35,830 - about/_head_body_template.html|pyg - DEBUG - Running FilterArtifact:about/_head_body_template.html|pyg::Doc:about/_head_body_template.html|pyg
    2012-11-19 23:27:35,830 - about/_head_body_template.html|pyg - DEBUG - Output is not cached under 9178200ceb4ed09bc39c82dbb5a7bf56, running...
    2012-11-19 23:27:35,852 - about/_head_body_template.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:36,063 - about/_head_body_template.html|pyg - DEBUG - Running FilterArtifact:about/_head_body_template.html|pyg::Doc:about/_head_body_template.html|pyg|-
    2012-11-19 23:27:36,064 - about/_head_body_template.html|pyg - DEBUG - Output is not cached under acc54891b2b22384f88c896ed6b06aae, running...
    2012-11-19 23:27:36,086 - about/_head_body_template.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:36,117 - about/_head_body_template.html|pyg|- - DEBUG - Running FilterArtifact:about/_head_body_template.html|pyg|-::Doc:about/_head_body_template.html|pyg|-
    2012-11-19 23:27:36,118 - about/_head_body_template.html|pyg|- - DEBUG - Output is not cached under 21f0887252d59463d4c53e3c63d7af96, running...

## about/_introspect_template.html|pyg|- ↑

#### Arguments

    ws_template: False
    canon: True

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
about/_introspect_template.html | artifacts/0c82ef73a0cf60dab40ba737db9c426c.html | 0.0001 |  |
about/_introspect_template.html|pyg | artifacts/aded6002a186af2d70d8c78dbf3ad7ec.html | 0.0307 | generated | 1
about/_introspect_template.html|pyg|- | artifacts/42a5517e3be478affb4ec84ef568536e.html | 0.0004 | generated |

#### Document Log

    2012-11-19 23:27:34,466 - about/_introspect_template.html|pyg - DEBUG - Setting up FilterArtifact:about/_introspect_template.html|pyg::Doc:about/_introspect_template.html|pyg
    2012-11-19 23:27:34,467 - about/_introspect_template.html|pyg - DEBUG - Setting hashstring for about/_introspect_template.html|pyg to f446a3577e67a18aea56f23b43b8eaa9
    2012-11-19 23:27:34,467 - about/_introspect_template.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,483 - about/_introspect_template.html|pyg - DEBUG - Setting up FilterArtifact:about/_introspect_template.html|pyg::Doc:about/_introspect_template.html|pyg|-
    2012-11-19 23:27:34,483 - about/_introspect_template.html|pyg - DEBUG - Setting hashstring for about/_introspect_template.html|pyg to aded6002a186af2d70d8c78dbf3ad7ec
    2012-11-19 23:27:34,483 - about/_introspect_template.html|pyg - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:34,483 - about/_introspect_template.html|pyg|- - DEBUG - Setting up FilterArtifact:about/_introspect_template.html|pyg|-::Doc:about/_introspect_template.html|pyg|-
    2012-11-19 23:27:34,484 - about/_introspect_template.html|pyg|- - DEBUG - Setting hashstring for about/_introspect_template.html|pyg|- to 42a5517e3be478affb4ec84ef568536e
    2012-11-19 23:27:34,484 - about/_introspect_template.html|pyg|- - DEBUG - setting up output data of class GenericData
    2012-11-19 23:27:35,895 - about/_introspect_template.html|pyg - DEBUG - Running FilterArtifact:about/_introspect_template.html|pyg::Doc:about/_introspect_template.html|pyg
    2012-11-19 23:27:35,895 - about/_introspect_template.html|pyg - DEBUG - Output is not cached under f446a3577e67a18aea56f23b43b8eaa9, running...
    2012-11-19 23:27:35,917 - about/_introspect_template.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:36,122 - about/_introspect_template.html|pyg - DEBUG - Running FilterArtifact:about/_introspect_template.html|pyg::Doc:about/_introspect_template.html|pyg|-
    2012-11-19 23:27:36,123 - about/_introspect_template.html|pyg - DEBUG - Output is not cached under aded6002a186af2d70d8c78dbf3ad7ec, running...
    2012-11-19 23:27:36,151 - about/_introspect_template.html|pyg - DEBUG - Using lexer HtmlLexer
    2012-11-19 23:27:36,153 - about/_introspect_template.html|pyg|- - DEBUG - Running FilterArtifact:about/_introspect_template.html|pyg|-::Doc:about/_introspect_template.html|pyg|-
    2012-11-19 23:27:36,153 - about/_introspect_template.html|pyg|- - DEBUG - Output is not cached under 42a5517e3be478affb4ec84ef568536e, running...

## about/index.md|jinja|markdown ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
about/index.md | artifacts/3d01035e5931d39dc8b3d72d2d627181.md | 0.0000 |  |
about/index.md|jinja | artifacts/09a665714df40f5a8835b3e1dd20ed4b.md | 0.0402 | generated |
about/index.md|jinja|markdown | artifacts/4dc2005da8ec049651ee33f1204bded6.html | 0.0161 | generated |

#### Document Log

    2012-11-19 23:27:34,485 - about/index.md|jinja - DEBUG - Setting up FilterArtifact:about/index.md|jinja::Doc:about/index.md|jinja|markdown
    2012-11-19 23:27:34,486 - about/index.md|jinja - DEBUG - Setting hashstring for about/index.md|jinja to 09a665714df40f5a8835b3e1dd20ed4b
    2012-11-19 23:27:34,486 - about/index.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-19 23:27:34,486 - about/index.md|jinja|markdown - DEBUG - Setting up FilterArtifact:about/index.md|jinja|markdown::Doc:about/index.md|jinja|markdown
    2012-11-19 23:27:34,487 - about/index.md|jinja|markdown - DEBUG - Setting hashstring for about/index.md|jinja|markdown to 4dc2005da8ec049651ee33f1204bded6
    2012-11-19 23:27:34,487 - about/index.md|jinja|markdown - DEBUG - setting up output data of class GenericData
    2012-11-19 23:27:36,154 - about/index.md|jinja - DEBUG - Running FilterArtifact:about/index.md|jinja::Doc:about/index.md|jinja|markdown
    2012-11-19 23:27:36,154 - about/index.md|jinja - DEBUG - Output is not cached under 09a665714df40f5a8835b3e1dd20ed4b, running...
    2012-11-19 23:27:36,166 - about/index.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/09a665714df40f5a8835b3e1dd20ed4b/about, artifacts/09a665714df40f5a8835b3e1dd20ed4b
    2012-11-19 23:27:36,167 - about/index.md|jinja - DEBUG - setting up jinja environment
    2012-11-19 23:27:36,167 - about/index.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-19 23:27:36,167 - about/index.md|jinja - DEBUG - initializing template
    2012-11-19 23:27:36,167 - about/index.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-19 23:27:36,167 - about/index.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-19 23:27:36,167 - about/index.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-19 23:27:36,168 - about/index.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-19 23:27:36,168 - about/index.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-19 23:27:36,168 - about/index.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-19 23:27:36,168 - about/index.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-19 23:27:36,168 - about/index.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-19 23:27:36,185 - about/index.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-19 23:27:36,185 - about/index.md|jinja - DEBUG - Running template plugin Variables
    2012-11-19 23:27:36,185 - about/index.md|jinja - DEBUG - Running template plugin Globals
    2012-11-19 23:27:36,186 - about/index.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-19 23:27:36,187 - about/index.md|jinja - DEBUG - relative refs are ['../_base.html-pyg.html', '../_base.html|pyg', '../_home_template.html-pyg.html', '../_home_template.html|pyg', '../_template.html-pyg.html', '../_template.html|pyg', '../dexy.conf-pyg.html', '../dexy.conf|pyg', '../dexy.yaml-idio.html', '../dexy.yaml|idio', '../index.html-pyg.html', '../index.html|pyg', '../list-reports.sh-shint-pyg.html', '../list-reports.sh|shint|pyg', '../macros/_banner.html-pyg--.html', '../macros/_banner.html-pyg.html', '../macros/_banner.html|pyg', '../macros/_banner.html|pyg|-', '../macros/_footer.html-pyg--.html', '../macros/_footer.html-pyg.html', '../macros/_footer.html|pyg', '../macros/_footer.html|pyg|-', '../macros/_header.html-pyg--.html', '../macros/_header.html-pyg.html', '../macros/_header.html|pyg', '../macros/_header.html|pyg|-', '../macros/_logo.html-pyg--.html', '../macros/_logo.html-pyg.html', '../macros/_logo.html|pyg', '../macros/_logo.html|pyg|-', '../macros/nav.jinja-pyg.html', '../macros/nav.jinja|pyg', '/_base.html-pyg.html', '/_base.html|pyg', '/_home_template.html-pyg.html', '/_home_template.html|pyg', '/_template.html-pyg.html', '/_template.html|pyg', '/about/_head_body_template.html-pyg--.html', '/about/_head_body_template.html-pyg.html', '/about/_head_body_template.html|pyg', '/about/_head_body_template.html|pyg|-', '/about/_introspect_template.html-pyg--.html', '/about/_introspect_template.html-pyg.html', '/about/_introspect_template.html|pyg', '/about/_introspect_template.html|pyg|-', '/about/_simple_template.html-pyg--.html', '/about/_simple_template.html-pyg.html', '/about/_simple_template.html|pyg', '/about/_simple_template.html|pyg|-', '/about/dexy.yaml-idio.html', '/about/dexy.yaml|idio', '/about/head_body_content.html-pyg.html', '/about/head_body_content.html|pyg', '/about/index.md', '/about/index.md-idio.html', '/about/index.md|idio', '/about/simple_content.html-pyg.html', '/about/simple_content.html|pyg', '/dexy.conf-pyg.html', '/dexy.conf|pyg', '/dexy.yaml-idio.html', '/dexy.yaml|idio', '/index.html-pyg.html', '/index.html|pyg', '/list-reports.sh-shint-pyg.html', '/list-reports.sh|shint|pyg', '/macros/_banner.html-pyg--.html', '/macros/_banner.html-pyg.html', '/macros/_banner.html|pyg', '/macros/_banner.html|pyg|-', '/macros/_footer.html-pyg--.html', '/macros/_footer.html-pyg.html', '/macros/_footer.html|pyg', '/macros/_footer.html|pyg|-', '/macros/_header.html-pyg--.html', '/macros/_header.html-pyg.html', '/macros/_header.html|pyg', '/macros/_header.html|pyg|-', '/macros/_logo.html-pyg--.html', '/macros/_logo.html-pyg.html', '/macros/_logo.html|pyg', '/macros/_logo.html|pyg|-', '/macros/nav.jinja-pyg.html', '/macros/nav.jinja|pyg', '_head_body_template.html-pyg--.html', '_head_body_template.html-pyg.html', '_head_body_template.html|pyg', '_head_body_template.html|pyg|-', '_introspect_template.html-pyg--.html', '_introspect_template.html-pyg.html', '_introspect_template.html|pyg', '_introspect_template.html|pyg|-', '_simple_template.html-pyg--.html', '_simple_template.html-pyg.html', '_simple_template.html|pyg', '_simple_template.html|pyg|-', 'dexy.yaml-idio.html', 'dexy.yaml|idio', 'head_body_content.html-pyg.html', 'head_body_content.html|pyg', 'index.md', 'index.md-idio.html', 'index.md|idio', 'simple_content.html-pyg.html', 'simple_content.html|pyg']
    2012-11-19 23:27:36,188 - about/index.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-19 23:27:36,188 - about/index.md|jinja - DEBUG - about to create jinja template
    2012-11-19 23:27:36,194 - about/index.md|jinja - DEBUG - about to process jinja template
    2012-11-19 23:27:36,194 - about/index.md|jinja|markdown - DEBUG - Running FilterArtifact:about/index.md|jinja|markdown::Doc:about/index.md|jinja|markdown
    2012-11-19 23:27:36,195 - about/index.md|jinja|markdown - DEBUG - Output is not cached under 4dc2005da8ec049651ee33f1204bded6, running...
    2012-11-19 23:27:36,195 - about/index.md|jinja|markdown - DEBUG - Initializing Markdown with extensions: ["toc"] and extension configs: {"toc": {}}

## css/pygments.css ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
css/pygments.css | artifacts/8f74d158ea7111eb06e9c78adfca4edc.css | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,487 - css/pygments.css - DEBUG - Setting up InitialArtifact:css/pygments.css::Doc:css/pygments.css
    2012-11-19 23:27:34,487 - css/pygments.css - DEBUG - Setting hashstring for css/pygments.css to 8f74d158ea7111eb06e9c78adfca4edc
    2012-11-19 23:27:34,488 - css/pygments.css - DEBUG - setting up output data of class GenericData

## css/style-desktop.css ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
css/style-desktop.css | artifacts/fea9047cf8d9b647a147783acf50301e.css | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,488 - css/style-desktop.css - DEBUG - Setting up InitialArtifact:css/style-desktop.css::Doc:css/style-desktop.css
    2012-11-19 23:27:34,488 - css/style-desktop.css - DEBUG - Setting hashstring for css/style-desktop.css to fea9047cf8d9b647a147783acf50301e
    2012-11-19 23:27:34,488 - css/style-desktop.css - DEBUG - setting up output data of class GenericData

## css/style-mobile.css ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
css/style-mobile.css | artifacts/ae7c34a304ffc839dadef77482ded50e.css | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,488 - css/style-mobile.css - DEBUG - Setting up InitialArtifact:css/style-mobile.css::Doc:css/style-mobile.css
    2012-11-19 23:27:34,488 - css/style-mobile.css - DEBUG - Setting hashstring for css/style-mobile.css to ae7c34a304ffc839dadef77482ded50e
    2012-11-19 23:27:34,489 - css/style-mobile.css - DEBUG - setting up output data of class GenericData

## css/style.css ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
css/style.css | artifacts/a367a4f5de2271964ab090e6d864eb4b.css | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,489 - css/style.css - DEBUG - Setting up InitialArtifact:css/style.css::Doc:css/style.css
    2012-11-19 23:27:34,489 - css/style.css - DEBUG - Setting hashstring for css/style.css to a367a4f5de2271964ab090e6d864eb4b
    2012-11-19 23:27:34,489 - css/style.css - DEBUG - setting up output data of class GenericData

## css/style-1000px.css ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
css/style-1000px.css | artifacts/9d1d14d4ef59fea091516357bbffa43f.css | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,489 - css/style-1000px.css - DEBUG - Setting up InitialArtifact:css/style-1000px.css::Doc:css/style-1000px.css
    2012-11-19 23:27:34,490 - css/style-1000px.css - DEBUG - Setting hashstring for css/style-1000px.css to 9d1d14d4ef59fea091516357bbffa43f
    2012-11-19 23:27:34,490 - css/style-1000px.css - DEBUG - setting up output data of class GenericData

## css/5grid/core-mobile.css ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
css/5grid/core-mobile.css | artifacts/5c4d623f4dfe7da9e3690b0706aea294.css | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,490 - css/5grid/core-mobile.css - DEBUG - Setting up InitialArtifact:css/5grid/core-mobile.css::Doc:css/5grid/core-mobile.css
    2012-11-19 23:27:34,490 - css/5grid/core-mobile.css - DEBUG - Setting hashstring for css/5grid/core-mobile.css to 5c4d623f4dfe7da9e3690b0706aea294
    2012-11-19 23:27:34,490 - css/5grid/core-mobile.css - DEBUG - setting up output data of class GenericData

## css/5grid/core-fluid.css ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
css/5grid/core-fluid.css | artifacts/dbf278ab53cb8ead0f3d886754403f48.css | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,491 - css/5grid/core-fluid.css - DEBUG - Setting up InitialArtifact:css/5grid/core-fluid.css::Doc:css/5grid/core-fluid.css
    2012-11-19 23:27:34,491 - css/5grid/core-fluid.css - DEBUG - Setting hashstring for css/5grid/core-fluid.css to dbf278ab53cb8ead0f3d886754403f48
    2012-11-19 23:27:34,491 - css/5grid/core-fluid.css - DEBUG - setting up output data of class GenericData

## css/5grid/mobileUI-beveled.css ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
css/5grid/mobileUI-beveled.css | artifacts/7c82958f0fa660a08f6a7ae2dd49b982.css | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,491 - css/5grid/mobileUI-beveled.css - DEBUG - Setting up InitialArtifact:css/5grid/mobileUI-beveled.css::Doc:css/5grid/mobileUI-beveled.css
    2012-11-19 23:27:34,491 - css/5grid/mobileUI-beveled.css - DEBUG - Setting hashstring for css/5grid/mobileUI-beveled.css to 7c82958f0fa660a08f6a7ae2dd49b982
    2012-11-19 23:27:34,492 - css/5grid/mobileUI-beveled.css - DEBUG - setting up output data of class GenericData

## css/5grid/core-1200px.css ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
css/5grid/core-1200px.css | artifacts/5c95740841d4c4fa874c812541562e0f.css | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,492 - css/5grid/core-1200px.css - DEBUG - Setting up InitialArtifact:css/5grid/core-1200px.css::Doc:css/5grid/core-1200px.css
    2012-11-19 23:27:34,492 - css/5grid/core-1200px.css - DEBUG - Setting hashstring for css/5grid/core-1200px.css to 5c95740841d4c4fa874c812541562e0f
    2012-11-19 23:27:34,492 - css/5grid/core-1200px.css - DEBUG - setting up output data of class GenericData

## css/5grid/core-1000px.css ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
css/5grid/core-1000px.css | artifacts/5cdf90e50bc856e7bc37c77134049127.css | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,493 - css/5grid/core-1000px.css - DEBUG - Setting up InitialArtifact:css/5grid/core-1000px.css::Doc:css/5grid/core-1000px.css
    2012-11-19 23:27:34,493 - css/5grid/core-1000px.css - DEBUG - Setting hashstring for css/5grid/core-1000px.css to 5cdf90e50bc856e7bc37c77134049127
    2012-11-19 23:27:34,493 - css/5grid/core-1000px.css - DEBUG - setting up output data of class GenericData

## css/5grid/core-noscript.css ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
css/5grid/core-noscript.css | artifacts/376c8d8f6eeba7d92f0ebaa2ff575784.css | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,494 - css/5grid/core-noscript.css - DEBUG - Setting up InitialArtifact:css/5grid/core-noscript.css::Doc:css/5grid/core-noscript.css
    2012-11-19 23:27:34,494 - css/5grid/core-noscript.css - DEBUG - Setting hashstring for css/5grid/core-noscript.css to 376c8d8f6eeba7d92f0ebaa2ff575784
    2012-11-19 23:27:34,494 - css/5grid/core-noscript.css - DEBUG - setting up output data of class GenericData

## css/5grid/mobileUI-flat.css ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
css/5grid/mobileUI-flat.css | artifacts/b358e672333d2aa3df327f4790e46484.css | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,495 - css/5grid/mobileUI-flat.css - DEBUG - Setting up InitialArtifact:css/5grid/mobileUI-flat.css::Doc:css/5grid/mobileUI-flat.css
    2012-11-19 23:27:34,495 - css/5grid/mobileUI-flat.css - DEBUG - Setting hashstring for css/5grid/mobileUI-flat.css to b358e672333d2aa3df327f4790e46484
    2012-11-19 23:27:34,495 - css/5grid/mobileUI-flat.css - DEBUG - setting up output data of class GenericData

## css/5grid/core.css ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
css/5grid/core.css | artifacts/25996d59f2dbb6a3048c44a910bd0dc4.css | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,496 - css/5grid/core.css - DEBUG - Setting up InitialArtifact:css/5grid/core.css::Doc:css/5grid/core.css
    2012-11-19 23:27:34,496 - css/5grid/core.css - DEBUG - Setting hashstring for css/5grid/core.css to 25996d59f2dbb6a3048c44a910bd0dc4
    2012-11-19 23:27:34,496 - css/5grid/core.css - DEBUG - setting up output data of class GenericData

## css/5grid/core-desktop.css ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
css/5grid/core-desktop.css | artifacts/77885e2ed8bc84f0c8eb901c946dff64.css | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,497 - css/5grid/core-desktop.css - DEBUG - Setting up InitialArtifact:css/5grid/core-desktop.css::Doc:css/5grid/core-desktop.css
    2012-11-19 23:27:34,497 - css/5grid/core-desktop.css - DEBUG - Setting hashstring for css/5grid/core-desktop.css to 77885e2ed8bc84f0c8eb901c946dff64
    2012-11-19 23:27:34,497 - css/5grid/core-desktop.css - DEBUG - setting up output data of class GenericData

## css/5grid/init.js ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
css/5grid/init.js | artifacts/2f3271648f1e0aa6f0996661f9dda5c8.js | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,497 - css/5grid/init.js - DEBUG - Setting up InitialArtifact:css/5grid/init.js::Doc:css/5grid/init.js
    2012-11-19 23:27:34,497 - css/5grid/init.js - DEBUG - Setting hashstring for css/5grid/init.js to 2f3271648f1e0aa6f0996661f9dda5c8
    2012-11-19 23:27:34,497 - css/5grid/init.js - DEBUG - setting up output data of class GenericData

## css/5grid/html5shiv.js ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
css/5grid/html5shiv.js | artifacts/9121b7bbc7a30b457a5af7501fe6e034.js | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,498 - css/5grid/html5shiv.js - DEBUG - Setting up InitialArtifact:css/5grid/html5shiv.js::Doc:css/5grid/html5shiv.js
    2012-11-19 23:27:34,498 - css/5grid/html5shiv.js - DEBUG - Setting hashstring for css/5grid/html5shiv.js to 9121b7bbc7a30b457a5af7501fe6e034
    2012-11-19 23:27:34,498 - css/5grid/html5shiv.js - DEBUG - setting up output data of class GenericData

## css/5grid/jquery.js ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
css/5grid/jquery.js | artifacts/cd54d0bcfadef41a8c3d43a00a2356a6.js | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,498 - css/5grid/jquery.js - DEBUG - Setting up InitialArtifact:css/5grid/jquery.js::Doc:css/5grid/jquery.js
    2012-11-19 23:27:34,498 - css/5grid/jquery.js - DEBUG - Setting hashstring for css/5grid/jquery.js to cd54d0bcfadef41a8c3d43a00a2356a6
    2012-11-19 23:27:34,499 - css/5grid/jquery.js - DEBUG - setting up output data of class GenericData

## images/img17.png ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img17.png | artifacts/a18a4504c73ed5c407a4c6c1f6661dcb.png | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,499 - images/img17.png - DEBUG - Setting up InitialArtifact:images/img17.png::Doc:images/img17.png
    2012-11-19 23:27:34,499 - images/img17.png - DEBUG - Setting hashstring for images/img17.png to a18a4504c73ed5c407a4c6c1f6661dcb
    2012-11-19 23:27:34,499 - images/img17.png - DEBUG - setting up output data of class GenericData

## images/img18.png ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img18.png | artifacts/1a839539ebe79be9bdec9f6eefcd365f.png | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,499 - images/img18.png - DEBUG - Setting up InitialArtifact:images/img18.png::Doc:images/img18.png
    2012-11-19 23:27:34,500 - images/img18.png - DEBUG - Setting hashstring for images/img18.png to 1a839539ebe79be9bdec9f6eefcd365f
    2012-11-19 23:27:34,500 - images/img18.png - DEBUG - setting up output data of class GenericData

## images/img04.png ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img04.png | artifacts/3a03ec9eec4228f591c151aa050276db.png | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,500 - images/img04.png - DEBUG - Setting up InitialArtifact:images/img04.png::Doc:images/img04.png
    2012-11-19 23:27:34,500 - images/img04.png - DEBUG - Setting hashstring for images/img04.png to 3a03ec9eec4228f591c151aa050276db
    2012-11-19 23:27:34,500 - images/img04.png - DEBUG - setting up output data of class GenericData

## images/img10.jpg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img10.jpg | artifacts/f34d7416d2f4efdf474f56f8b55f12fe.jpg | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,500 - images/img10.jpg - DEBUG - Setting up InitialArtifact:images/img10.jpg::Doc:images/img10.jpg
    2012-11-19 23:27:34,501 - images/img10.jpg - DEBUG - Setting hashstring for images/img10.jpg to f34d7416d2f4efdf474f56f8b55f12fe
    2012-11-19 23:27:34,501 - images/img10.jpg - DEBUG - setting up output data of class GenericData

## images/img16.jpg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img16.jpg | artifacts/fa81e158a2e742f26f3a453e1ce5acd1.jpg | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,501 - images/img16.jpg - DEBUG - Setting up InitialArtifact:images/img16.jpg::Doc:images/img16.jpg
    2012-11-19 23:27:34,501 - images/img16.jpg - DEBUG - Setting hashstring for images/img16.jpg to fa81e158a2e742f26f3a453e1ce5acd1
    2012-11-19 23:27:34,501 - images/img16.jpg - DEBUG - setting up output data of class GenericData

## images/img09.jpg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img09.jpg | artifacts/aa6c7baa6a2ee3256ea8b9a0c5150780.jpg | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,502 - images/img09.jpg - DEBUG - Setting up InitialArtifact:images/img09.jpg::Doc:images/img09.jpg
    2012-11-19 23:27:34,502 - images/img09.jpg - DEBUG - Setting hashstring for images/img09.jpg to aa6c7baa6a2ee3256ea8b9a0c5150780
    2012-11-19 23:27:34,502 - images/img09.jpg - DEBUG - setting up output data of class GenericData

## images/img11.jpg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img11.jpg | artifacts/bd156c9b2b0ef5f949db1983fe860798.jpg | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,502 - images/img11.jpg - DEBUG - Setting up InitialArtifact:images/img11.jpg::Doc:images/img11.jpg
    2012-11-19 23:27:34,502 - images/img11.jpg - DEBUG - Setting hashstring for images/img11.jpg to bd156c9b2b0ef5f949db1983fe860798
    2012-11-19 23:27:34,502 - images/img11.jpg - DEBUG - setting up output data of class GenericData

## images/img12.jpg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img12.jpg | artifacts/ba6ab7c45e08d8b3995e3af0869a34a8.jpg | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,503 - images/img12.jpg - DEBUG - Setting up InitialArtifact:images/img12.jpg::Doc:images/img12.jpg
    2012-11-19 23:27:34,503 - images/img12.jpg - DEBUG - Setting hashstring for images/img12.jpg to ba6ab7c45e08d8b3995e3af0869a34a8
    2012-11-19 23:27:34,503 - images/img12.jpg - DEBUG - setting up output data of class GenericData

## images/img14.jpg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img14.jpg | artifacts/41de90ddf52d2458b964818463af580f.jpg | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,504 - images/img14.jpg - DEBUG - Setting up InitialArtifact:images/img14.jpg::Doc:images/img14.jpg
    2012-11-19 23:27:34,504 - images/img14.jpg - DEBUG - Setting hashstring for images/img14.jpg to 41de90ddf52d2458b964818463af580f
    2012-11-19 23:27:34,504 - images/img14.jpg - DEBUG - setting up output data of class GenericData

## images/img15.jpg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img15.jpg | artifacts/7dfd2fec4a07111030e167b4c0b48da3.jpg | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,504 - images/img15.jpg - DEBUG - Setting up InitialArtifact:images/img15.jpg::Doc:images/img15.jpg
    2012-11-19 23:27:34,504 - images/img15.jpg - DEBUG - Setting hashstring for images/img15.jpg to 7dfd2fec4a07111030e167b4c0b48da3
    2012-11-19 23:27:34,504 - images/img15.jpg - DEBUG - setting up output data of class GenericData

## images/img21.jpg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img21.jpg | artifacts/ccd46e3b7d92b8242b1145fa43a0d56a.jpg | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,505 - images/img21.jpg - DEBUG - Setting up InitialArtifact:images/img21.jpg::Doc:images/img21.jpg
    2012-11-19 23:27:34,505 - images/img21.jpg - DEBUG - Setting hashstring for images/img21.jpg to ccd46e3b7d92b8242b1145fa43a0d56a
    2012-11-19 23:27:34,505 - images/img21.jpg - DEBUG - setting up output data of class GenericData

## images/img20.jpg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img20.jpg | artifacts/4f5db090c9b9bd192897952416733253.jpg | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,506 - images/img20.jpg - DEBUG - Setting up InitialArtifact:images/img20.jpg::Doc:images/img20.jpg
    2012-11-19 23:27:34,506 - images/img20.jpg - DEBUG - Setting hashstring for images/img20.jpg to 4f5db090c9b9bd192897952416733253
    2012-11-19 23:27:34,506 - images/img20.jpg - DEBUG - setting up output data of class GenericData

## images/img19.jpg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img19.jpg | artifacts/abedbf45ffb3beacef0494517b12faf2.jpg | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,506 - images/img19.jpg - DEBUG - Setting up InitialArtifact:images/img19.jpg::Doc:images/img19.jpg
    2012-11-19 23:27:34,507 - images/img19.jpg - DEBUG - Setting hashstring for images/img19.jpg to abedbf45ffb3beacef0494517b12faf2
    2012-11-19 23:27:34,507 - images/img19.jpg - DEBUG - setting up output data of class GenericData

## images/img05.jpg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img05.jpg | artifacts/ef025aa1b8f9fe3a7b29f67e591c76cb.jpg | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,507 - images/img05.jpg - DEBUG - Setting up InitialArtifact:images/img05.jpg::Doc:images/img05.jpg
    2012-11-19 23:27:34,507 - images/img05.jpg - DEBUG - Setting hashstring for images/img05.jpg to ef025aa1b8f9fe3a7b29f67e591c76cb
    2012-11-19 23:27:34,508 - images/img05.jpg - DEBUG - setting up output data of class GenericData

## images/img17.jpg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img17.jpg | artifacts/d859ea37fbcca453ba90a0cbece5f15d.jpg | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,508 - images/img17.jpg - DEBUG - Setting up InitialArtifact:images/img17.jpg::Doc:images/img17.jpg
    2012-11-19 23:27:34,508 - images/img17.jpg - DEBUG - Setting hashstring for images/img17.jpg to d859ea37fbcca453ba90a0cbece5f15d
    2012-11-19 23:27:34,508 - images/img17.jpg - DEBUG - setting up output data of class GenericData

## images/img02.jpg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img02.jpg | artifacts/cbb2e2ca502114446b94c61aaeb9ef4a.jpg | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,509 - images/img02.jpg - DEBUG - Setting up InitialArtifact:images/img02.jpg::Doc:images/img02.jpg
    2012-11-19 23:27:34,509 - images/img02.jpg - DEBUG - Setting hashstring for images/img02.jpg to cbb2e2ca502114446b94c61aaeb9ef4a
    2012-11-19 23:27:34,509 - images/img02.jpg - DEBUG - setting up output data of class GenericData

## images/img07.jpg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img07.jpg | artifacts/af4012027ecf1f8a61f26a118fb36bde.jpg | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,510 - images/img07.jpg - DEBUG - Setting up InitialArtifact:images/img07.jpg::Doc:images/img07.jpg
    2012-11-19 23:27:34,510 - images/img07.jpg - DEBUG - Setting hashstring for images/img07.jpg to af4012027ecf1f8a61f26a118fb36bde
    2012-11-19 23:27:34,510 - images/img07.jpg - DEBUG - setting up output data of class GenericData

## images/img01.jpg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img01.jpg | artifacts/94a4b10bc6cede9b8b7c16fa39ab68f7.jpg | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,511 - images/img01.jpg - DEBUG - Setting up InitialArtifact:images/img01.jpg::Doc:images/img01.jpg
    2012-11-19 23:27:34,511 - images/img01.jpg - DEBUG - Setting hashstring for images/img01.jpg to 94a4b10bc6cede9b8b7c16fa39ab68f7
    2012-11-19 23:27:34,511 - images/img01.jpg - DEBUG - setting up output data of class GenericData

## images/img13.jpg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img13.jpg | artifacts/99c962dc2bb26b7705bae285a489da41.jpg | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,512 - images/img13.jpg - DEBUG - Setting up InitialArtifact:images/img13.jpg::Doc:images/img13.jpg
    2012-11-19 23:27:34,512 - images/img13.jpg - DEBUG - Setting hashstring for images/img13.jpg to 99c962dc2bb26b7705bae285a489da41
    2012-11-19 23:27:34,512 - images/img13.jpg - DEBUG - setting up output data of class GenericData

## images/img03.jpg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img03.jpg | artifacts/c7181a5d4abb26c1ae631c8e722f8a3a.jpg | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,513 - images/img03.jpg - DEBUG - Setting up InitialArtifact:images/img03.jpg::Doc:images/img03.jpg
    2012-11-19 23:27:34,513 - images/img03.jpg - DEBUG - Setting hashstring for images/img03.jpg to c7181a5d4abb26c1ae631c8e722f8a3a
    2012-11-19 23:27:34,514 - images/img03.jpg - DEBUG - setting up output data of class GenericData

## images/img06.jpg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img06.jpg | artifacts/433f91f9e00dd9324e2428bf57525340.jpg | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,515 - images/img06.jpg - DEBUG - Setting up InitialArtifact:images/img06.jpg::Doc:images/img06.jpg
    2012-11-19 23:27:34,515 - images/img06.jpg - DEBUG - Setting hashstring for images/img06.jpg to 433f91f9e00dd9324e2428bf57525340
    2012-11-19 23:27:34,515 - images/img06.jpg - DEBUG - setting up output data of class GenericData

## images/img08.jpg ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
images/img08.jpg | artifacts/75af56d8c7b07f25037311b3392f1b23.jpg | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,516 - images/img08.jpg - DEBUG - Setting up InitialArtifact:images/img08.jpg::Doc:images/img08.jpg
    2012-11-19 23:27:34,516 - images/img08.jpg - DEBUG - Setting hashstring for images/img08.jpg to 75af56d8c7b07f25037311b3392f1b23
    2012-11-19 23:27:34,516 - images/img08.jpg - DEBUG - setting up output data of class GenericData

## ./about/simple_content.html ↑

#### Arguments

    ws_template: _simple_template.html

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
./about/simple_content.html | artifacts/15ca0272911abd949c9400ef5c66e217.html | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,516 - ./about/simple_content.html - DEBUG - Setting up InitialArtifact:./about/simple_content.html::Doc:./about/simple_content.html
    2012-11-19 23:27:34,517 - ./about/simple_content.html - DEBUG - Setting hashstring for ./about/simple_content.html to 15ca0272911abd949c9400ef5c66e217
    2012-11-19 23:27:34,517 - ./about/simple_content.html - DEBUG - setting up output data of class GenericData

## ./about/head_body_content.html|htmlsections ↑

#### Arguments

    ws_template: _head_body_template.html

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
./about/head_body_content.html | artifacts/42e6a2dca03ead492ee720f8e537adf4.html | 0.0000 |  |
./about/head_body_content.html|htmlsections | artifacts/9115fe2d7961b4e45869032fbf06bbc2.json | 0.0008 | generated | head body

#### Document Log

    2012-11-19 23:27:34,517 - ./about/head_body_content.html|htmlsections - DEBUG - Setting up FilterArtifact:./about/head_body_content.html|htmlsections::Doc:./about/head_body_content.html|htmlsections
    2012-11-19 23:27:34,518 - ./about/head_body_content.html|htmlsections - DEBUG - Setting hashstring for ./about/head_body_content.html|htmlsections to 9115fe2d7961b4e45869032fbf06bbc2
    2012-11-19 23:27:34,518 - ./about/head_body_content.html|htmlsections - DEBUG - setting up output data of class SectionedData
    2012-11-19 23:27:36,228 - ./about/head_body_content.html|htmlsections - DEBUG - Running FilterArtifact:./about/head_body_content.html|htmlsections::Doc:./about/head_body_content.html|htmlsections
    2012-11-19 23:27:36,228 - ./about/head_body_content.html|htmlsections - DEBUG - Output is not cached under 9115fe2d7961b4e45869032fbf06bbc2, running...

## ./about/introspect.html ↑

#### Arguments

    ws_template: _introspect_template.html

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
./about/introspect.html | artifacts/cfe32545e90f4855e326224dfd1467f4.html | 0.0000 |  |

#### Document Log

    2012-11-19 23:27:34,518 - ./about/introspect.html - DEBUG - Setting up InitialVirtualArtifact:./about/introspect.html::Doc:./about/introspect.html
    2012-11-19 23:27:34,518 - ./about/introspect.html - DEBUG - Setting hashstring for ./about/introspect.html to cfe32545e90f4855e326224dfd1467f4
    2012-11-19 23:27:34,518 - ./about/introspect.html - DEBUG - setting up output data of class GenericData